@@ -353,12 +353,11 @@ def download_commit_db_images(url_images, url_produits):
     else:
         for product in url_produits.keys():
             try:
-                for img in url_produits[product]['images']:
-                    download_or_remove(img, product,
-                                       url_produits.get(product, {}).get("customer_name"),
-                                       url_produits.get(product, {}).get('customer_type'), db,
-                                       url_produits.get(product, {}).get('path'),
-                                       url_produits.get(product, {}).get('project_name'))
+                download_or_remove(url_produits.get(product, {}).get('images', ''), product,
+                                   url_produits.get(product, {}).get("customer_name"),
+                                   url_produits.get(product, {}).get('customer_type'), db,
+                                   url_produits.get(product, {}).get('path'),
+                                   url_produits.get(product, {}).get('project_name'))
             except Exception as e:
                 logger.error('Error_url_produits_download_commit_db_images_cont %s downloading image %s continue' %
                              (e, url_produits[product]['images']))
