@@ -28,6 +28,8 @@ from keras.backend.tensorflow_backend import set_session
 from keras.backend.tensorflow_backend import clear_session
 from keras.backend.tensorflow_backend import get_session
 import tensorflow, gc
+import time
+import sys
 
 
 # Reset Keras Session
@@ -57,12 +59,21 @@ def get_category(last_json, num_cat):
                     return None
 
 
+
+
+
+
 def write_to_file(status, last_json, path_new_file, category_will_have_changes=None, block_image_n=None,
                   new_file=False):
-    try:
-        json_value = json.loads(path_new_file)
-    except Exception as e:
+    if os.path.isfile(path_new_file):
+        logger.info("-----path_new_file: %s"% path_new_file)
+        #json_value = json.loads(path_new_file)
+        with open(str(path_new_file), 'r') as content_file:
+            content = content_file.read()
+        json_value = json.loads(content)
+    else:
         json_value = {}
+    logger.info("----delta: creating file...")
     new_obj = {}
     key = ""
     try:
@@ -80,16 +91,48 @@ def write_to_file(status, last_json, path_new_file, category_will_have_changes=N
                         if str(product) == str(block_image_n):
                             photo = json_value[index_product]['Photos'][product]
                             photo["Status"] = status
+
+        new_obj[key] = json_value
+        with open(path_new_file, 'w') as outfile:
+            json.dump(new_obj, outfile)
+        outfile.close()
+        logger.info("-----delta file created")
     except Exception as e:
         logger.error("Erooor in_difff_files write_to_file %s" % e)
-    new_obj[key] = json_value
-    with open(path_new_file, 'w') as outfile:
-        json.dump(new_obj, outfile)
-    outfile.close()
-    return new_obj
+
+
+
+
+def add_category_and_write_to_file(status, last_json_path, last_json, new_category_objects, path_new_file):
+    try:
+        new_obj = dict()
+        for k, v in last_json.items():
+            for o in range(len(v)):
+                for p in range(len(v[o]['Photos'])):
+                    photo = v[o]['Photos'][p]
+                    photo["Status"] = 2
+
+                for obj in new_category_objects:
+                    if v[o] == obj:
+                        v[o] = obj
+                        photo['Status'] = status
+        new_obj[k] = v
+        with open(path_new_file, 'w') as outfile:
+            json.dump(new_obj, outfile)
+        outfile.close()
+        logger.info("----delta: added category and wrote to file")
+    except Exception as e:
+        logger.error("Error in_diff_files add_category_and_write_to_file %s" %e)
+
+
+
+
 
 
 def delta_retrieve_json(customer_name, customer_type, project_name):
+    logger.info("============> delta retrieve json started")
+    sys.setrecursionlimit(3000)
+    start = time.process_time()
     path_json = STREAMS_PATH + customer_type + '/' + customer_name + '/similars/' + project_name
     date = datetime.datetime.today().strftime("%Y-%m-%d:%H-%M")
     path_new_file = STREAMS_PATH + customer_type + '/' + customer_name + '/delta_files/' + project_name + '/'
@@ -108,6 +151,8 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
     if len(paths) > 1:
         last_json_path = paths[-1]
         before_last_json_path = paths[-2]
+        logger.info("******** "+before_last_json_path)
+        logger.info("******** "+last_json_path)
         last_json = json.load(open(last_json_path))
         before_last_json = json.load(open(before_last_json_path))
     elif len(paths) == 1:
@@ -124,6 +169,7 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
         difference = {}
     if before_last_json[customer_name + "_" + customer_type] != [] and difference != {} \
             and difference[customer_name + '_' + customer_type]:
+        logger.info("-----delta: comparing to existing file")
         for kcat, cat in difference[customer_name + '_' + customer_type].items():
             category_will_have_changes = get_category(last_json, kcat)
             if category_will_have_changes:
@@ -149,7 +195,10 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
 
             else:
                 try:
-                    for kphotos, photos in cat.items():
+                    logger.info("-----delta var = cat:")
+                    for kphotos, photos in cat[0].items():
+                        logger.info("-----delta var = photos:")
+                        logger.info(photos)
                         for kchanges, changes in photos.items():
                             if str(kchanges) == '$insert':
                                 status = 1
@@ -165,18 +214,46 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
                                     delete_block = before_last_json[customer_name + "_" + customer_type][kcat]['Photos'][block_image_n]
                                     delete_block["Status"] = 0
                                     last_json[customer_name + "_" + customer_type][kcat]['Photos'].append(delete_block)
+                except AttributeError as err:
+                    #only categories have changed not photos inside them
+                    new_category_objects = []
+                    if str(difference['okaidi_textile']).split(':')[0] == "{insert":
+                        status = 1
+                    elif str(difference['okaidi_textile']).split(':')[0] == "{delete":
+                        status = 0
+                    else:
+                        status = 2
+                    for tuplee in cat:
+                        #print(tuplee[1])
+                        new_category_objects.append(tuplee[1])
+                    add_category_and_write_to_file(status, last_json_path, last_json, new_category_objects, last_json)
                 except Exception as e:
                     logger.error("Erooor in_difff_files delta_retrieve_json %s" % e)
                     write_to_file(1, last_json, new_file_status)
 
         write_to_file(2, last_json, new_file_status)
     elif difference == {} and len(paths) > 1:
+        logger.info("-----delta: same file")
         write_to_file(2, last_json, new_file_status)
     else:
-        write_to_file(1, last_json, new_file_status, new_file=True)
+        logger.info("-----delta: 1st time, creating json")
+        try:
+            write_to_file(1, last_json, new_file_status, new_file=True)
+        except Exception as e:
+            logger.error(e)
+        logger.info("------delta: done creating file")
+    logger.info("-----Delta retrieve json compare time taken: "+str(time.process_time() - start))
     return new_file_status
 
 
+
+
+
+
+
+
+
+
 def load_labels(label_file):
     if '://' in label_file:
         response = urlopen(label_file)
@@ -282,9 +359,11 @@ def max_nb_images(path):
 
 
 def verif_folder_less_twenty(path, nb_classes):
+    #not actually verif less than 20 its just the name
     image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
     folder_less_20 = []
-    max_nb = max(round(nb_classes // BATCH_SIZE),max_nb_images(path))
+    #we will check if the number returned by max_nb_images is < batch size in this case it will cause error in training so we take max between it and batch/nb_classes
+    max_nb = max(round(BATCH_SIZE / nb_classes),max_nb_images(path))
     if max_nb < 20:
         max_nb = 20
     for j in os.listdir(path):
@@ -364,6 +443,7 @@ def classification_similars(customer_name, customer_type, project_name):
 
 def process_customer_stream_from_json(json_path, customer_name, customer_type, project_name):
     json_path = delta_retrieve_json(customer_name, customer_type, project_name)
+    logger.info("---- we are out of delta")
     request_post = api.apipost('retrieve_images_json', customer_name, customer_type, project_name, json_path)
     response_text = json.loads(request_post.text)
     response = response_text['response']
@@ -391,6 +471,7 @@ def process_customer_stream_from_json(json_path, customer_name, customer_type, p
         generate_similarity_vector(customer_name, customer_type, deleted_image, project_name)
 
 
+
 def process_customer_stream_cms(json_path, customer_name, customer_type, project_name):
     streams_path = STREAMS_PATH + customer_type + '/' + customer_name + '/similars/' + project_name + '/'+ \
                    'cms_json_file.json'
