@@ -106,12 +106,12 @@ def p_fwd__stripe_payment(payment, stripe_token, amount_in_cents, customer, cust
                 customer_id=cust.id,
                 currency=payment[7],
                 amount_in_cents=amount_to_pay,
-                description='Payement %s' % email,
+                description='Payement to foqus %s_%s' % (customer, customer_type),
                 order_id=payment[0]
             )
             date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
             db.update_transction_id(customer, customer_type, charge.id, plan_name, date, 'stripe')
-            subscribe_stripe_customer(cust.id, payment[5])
+            subscribe_stripe_customer(cust.id, plan_name)
         except Exception as e:
             logger.error('->ERROR<- %s' % e)
 
