@@ -19,6 +19,8 @@ from builtins import *
 from Augmentor.Operations import *
 from Augmentor.ImageUtilities import scan_directory, scan, scan_dataframe, AugmentorImage
 
+from foqus.functions_input import logger
+
 import os
 import sys
 import random
@@ -166,7 +168,7 @@ class Pipeline2(object):
                 try:
                     os.makedirs(abs_output_directory)
                 except IOError:
-                    print("Insufficient rights to read or write output directory (%s)"
+                    logger.info("Insufficient rights to read or write output directory (%s)"
                           % abs_output_directory)
         else:
             for class_label in self.class_labels:
@@ -174,7 +176,7 @@ class Pipeline2(object):
                     try:
                         os.makedirs(os.path.join(abs_output_directory, str(class_label[0])))
                     except IOError:
-                        print("Insufficient rights to read or write output directory (%s)"
+                        logger.info("Insufficient rights to read or write output directory (%s)"
                               % abs_output_directory)
         for augmentor_image in self.augmentor_images:
             try:
@@ -182,7 +184,7 @@ class Pipeline2(object):
                     self.distinct_dimensions.add(opened_image.size)
                     self.distinct_formats.add(opened_image.format)
             except IOError as e:
-                print("There is a problem with image %s in your source directory: %s"
+                logger.info("There is a problem with image %s in your source directory: %s"
                       % (augmentor_image.image_path, e.message))
                 self.augmentor_images.remove(augmentor_image)
 
@@ -248,9 +250,9 @@ class Pipeline2(object):
                         images[i].save(os.path.join(augmentor_image.output_directory, save_name))
 
             except IOError as e:
-                print("Error writing %s, %s. Change save_format to PNG?" % (file_name, e.message))
-                print("You can change the save format using the set_save_format(save_format) function.")
-                print("By passing save_format=\"auto\", Augmentor can save in the correct format automatically.")
+                logger.info("Error writing %s, %s. Change save_format to PNG?" % (file_name, e.message))
+                logger.info("You can change the save format using the set_save_format(save_format) function.")
+                logger.info("By passing save_format=\"auto\", Augmentor can save in the correct format automatically.")
 
         # TODO: Fix this really strange behaviour.
         # As a workaround, we can pass the same back and basically
@@ -644,15 +646,15 @@ class Pipeline2(object):
 
         .. code-block:: python
 
-            >>> import Augmentor
-            >>> import torchvision
-            >>> p = Augmentor.Pipeline()
-            >>> p.rotate(probability=0.7, max_left_rotate=10, max_right_rotate=10)
-            >>> p.zoom(probability=0.5, min_factor=1.1, max_factor=1.5)
-            >>> from keras.preprocessing.image import ImageDataGenerator
-            >>> datagen = ImageDataGenerator(
-            >>>     ...
-            >>>     preprocessing_function=p.keras_preprocess_func())
+            # >>> import Augmentor
+            # >>> import torchvision
+            # >>> p = Augmentor.Pipeline()
+            # >>> p.rotate(probability=0.7, max_left_rotate=10, max_right_rotate=10)
+            # >>> p.zoom(probability=0.5, min_factor=1.1, max_factor=1.5)
+            # >>> from keras.preprocessing.image import ImageDataGenerator
+            # >>> datagen = ImageDataGenerator(
+            # >>>     ...
+            # >>>     preprocessing_function=p.keras_preprocess_func())
 
         :return: The pipeline as a function.
         """
@@ -673,15 +675,15 @@ class Pipeline2(object):
 
         .. code-block:: python
 
-            >>> import Augmentor
-            >>> import torchvision
-            >>> p = Augmentor.Pipeline()
-            >>> p.rotate(probability=0.7, max_left_rotate=10, max_right_rotate=10)
-            >>> p.zoom(probability=0.5, min_factor=1.1, max_factor=1.5)
-            >>> transforms = torchvision.transforms.Compose([
-            >>>     p.torch_transform(),
-            >>>     torchvision.transforms.ToTensor(),
-            >>> ])
+            # >>> import Augmentor
+            # >>> import torchvision
+            # >>> p = Augmentor.Pipeline()
+            # >>> p.rotate(probability=0.7, max_left_rotate=10, max_right_rotate=10)
+            # >>> p.zoom(probability=0.5, min_factor=1.1, max_factor=1.5)
+            # >>> transforms = torchvision.transforms.Compose([
+            # >>>     p.torch_transform(),
+            # >>>     torchvision.transforms.ToTensor(),
+            # >>> ])
 
         :return: The pipeline as a function.
         """
@@ -769,36 +771,36 @@ class Pipeline2(object):
 
         :return: None
         """
-        # TODO: Return this as a dictionary of some kind and print from the dict if in console
-        print("Operations: %s" % len(self.operations))
+        # TODO: Return this as a dictionary of some kind and logger.info from the dict if in console
+        logger.info("Operations: %s" % len(self.operations))
 
         if len(self.operations) != 0:
             operation_index = 0
             for operation in self.operations:
-                print("\t%s: %s (" % (operation_index, operation), end="")
+                logger.info("\t%s: %s (" % (operation_index, operation), end="")
                 for operation_attribute, operation_value in operation.__dict__.items():
-                    print("%s=%s " % (operation_attribute, operation_value), end="")
-                print(")")
+                    logger.info("%s=%s " % (operation_attribute, operation_value), end="")
+                logger.info(")")
                 operation_index += 1
 
-        print("Images: %s" % len(self.augmentor_images))
+        logger.info("Images: %s" % len(self.augmentor_images))
 
         label_pairs = sorted(set([x.label_pair for x in self.augmentor_images]))
 
-        print("Classes: %s" % len(label_pairs))
+        logger.info("Classes: %s" % len(label_pairs))
 
         for label_pair in label_pairs:
-            print ("\tClass index: %s Class label: %s " % (label_pair[0], label_pair[1]))
+            logger.info ("\tClass index: %s Class label: %s " % (label_pair[0], label_pair[1]))
 
         if len(self.augmentor_images) != 0:
-            print("Dimensions: %s" % len(self.distinct_dimensions))
+            logger.info("Dimensions: %s" % len(self.distinct_dimensions))
             for distinct_dimension in self.distinct_dimensions:
-                print("\tWidth: %s Height: %s" % (distinct_dimension[0], distinct_dimension[1]))
-            print("Formats: %s" % len(self.distinct_formats))
+                logger.info("\tWidth: %s Height: %s" % (distinct_dimension[0], distinct_dimension[1]))
+            logger.info("Formats: %s" % len(self.distinct_formats))
             for distinct_format in self.distinct_formats:
-                print("\t %s" % distinct_format)
+                logger.info("\t %s" % distinct_format)
 
-        print("\nYou can remove operations using the appropriate index and the remove_operation(index) function.")
+        logger.info("\nYou can remove operations using the appropriate index and the remove_operation(index) function.")
 
     @staticmethod
     def set_seed(seed):
@@ -1705,7 +1707,7 @@ class Pipeline2(object):
         if num_of_ground_truth_images_added != 0:
             self.process_ground_truth_images = True
 
-        print("%s ground truth image(s) found." % num_of_ground_truth_images_added)
+        logger.info("%s ground truth image(s) found." % num_of_ground_truth_images_added)
 
     def get_ground_truth_paths(self):
         """
@@ -1719,7 +1721,7 @@ class Pipeline2(object):
         paths = []
 
         for augmentor_image in self.augmentor_images:
-            print("Image path: %s\nGround truth path: %s\n---\n" % (augmentor_image.image_path, augmentor_image.ground_truth))
+            logger.info("Image path: %s\nGround truth path: %s\n---\n" % (augmentor_image.image_path, augmentor_image.ground_truth))
             paths.append((augmentor_image.image_path, augmentor_image.ground_truth))
 
         return paths
